<?php

// phpcs:disable PSR1.Files.SideEffects

/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2022 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

use XrayProfiler\Log;
use XrayProfiler\CollectorShortcode;

if (defined('ABSPATH') && defined('WPINC') && function_exists('add_filter') && function_exists('json_encode')) {
    if (!defined('XRAY_RELEASE')) {
        define('XRAY_RELEASE', '0.5-11.el7');
    }

    try {
        include 'classes/xray-profiler-log.php';

        if (!function_exists('xray_profiler_log')) {
            /**
             * @param int $errno
             * @param string $errstr
             * @param  ?string $errfile
             * @param  ?int $errline
             *
             * @return void
             */
            function xray_profiler_log($errno, $errstr, $errfile = null, $errline = null)
            {
                if (class_exists('\XrayProfiler\Log')) {
                    Log::instance()->setData($errno, $errstr, $errfile, $errline);
                }
            }
        } else {
            return;
        }

        // Send log
        if (!function_exists('xray_profiler_send_log')) {
            /**
             * @return void
             */
            function xray_profiler_send_log()
            {
                if (class_exists('\XrayProfiler\Log')) {
                    Log::instance()->sendData();
                }
            }

            register_shutdown_function('xray_profiler_send_log');
        }
    } catch (Exception $e) {
        return;
    }

    try {
        include 'classes/xray-profiler-collector.php';
        include 'classes/xray-profiler-collector-shortcodes.php';

        if (!function_exists('xray_profiler_set_error_handler')) {
            /**
             * @return void
             */
            function xray_profiler_set_error_handler()
            {
                set_error_handler(function ($errno, $errstr, $errfile, $errline) {
                    xray_profiler_log($errno, $errstr, $errfile, $errline);
                    return true;
                }, E_ALL);
            }
        }

        if (!function_exists('xray_profiler_restore_error_handler')) {
            /**
             * @return void
             */
            function xray_profiler_restore_error_handler()
            {
                restore_error_handler();
            }
        }

        if (!function_exists('xray_profiler_get_shortcodes_data')) {
            /**
             * @return string
             */
            function xray_profiler_get_shortcodes_data()
            {
                $result = '';

                if (class_exists('\XrayProfiler\CollectorShortcode')) {
                    xray_profiler_set_error_handler();

                    $xray_data = [
                        'shortcodes' => CollectorShortcode::instance()->getXrayData(),
                    ];

                    if (!($json = json_encode($xray_data))) {
                        trigger_error("Can't prepare json for " . __METHOD__, 2);
                    } else {
                        $result = $json;
                    }

                    xray_profiler_restore_error_handler();
                }

                return $result;
            }
        }

        // Filters
        if (class_exists('\XrayProfiler\CollectorShortcode')) {
            $priority = defined('PHP_INT_MIN') ? PHP_INT_MIN : 0 - PHP_INT_MAX;

            add_filter('pre_do_shortcode_tag', function ($return, $tag, $attr, $m) {
                xray_profiler_set_error_handler();
                $return = CollectorShortcode::instance()->preDoShortcodeTagEarly($return, $tag, $attr, $m);
                xray_profiler_restore_error_handler();
                return $return;
            }, $priority, 4);

            add_filter('pre_do_shortcode_tag', function ($return, $tag, $attr, $m) {
                xray_profiler_set_error_handler();
                $return = CollectorShortcode::instance()->preDoShortcodeTagLate($return, $tag, $attr, $m);
                xray_profiler_restore_error_handler();
                return $return;
            }, PHP_INT_MAX, 4);

            add_filter('do_shortcode_tag', function ($output, $tag, $attr, $m) {
                xray_profiler_set_error_handler();
                $output = CollectorShortcode::instance()->doShortcodeTagLate($output, $tag, $attr, $m);
                xray_profiler_restore_error_handler();
                return $output;
            }, PHP_INT_MAX, 4);
        }
    } catch (Exception $e) {
        xray_profiler_log(E_USER_WARNING, $e->getMessage(), $e->getFile(), $e->getLine());
    }
}
