<?php
/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2022 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.
 * cloudlinux.
 * com/legal/
 */

namespace CloudLinux\SmartAdvice\App\Advice;

use CloudLinux\SmartAdvice\App\Model as BaseModel;

/**
 * Advice model
 */
class Model extends BaseModel {
	/**
	 * Advice ID.
	 *
	 * @var int
	 */
	public $id = 0;

	/**
	 * Advice type.
	 *
	 * @var string
	 */
	public $type = '';

	/**
	 * Advice status.
	 *
	 * @var string
	 */
	public $status = '';

	/**
	 * Advice short description.
	 *
	 * @var string
	 */
	public $description = '';

	/**
	 * Advice detail description.
	 *
	 * @var string
	 */
	public $detailed_description = '';

	/**
	 * Advice total stages.
	 *
	 * @var int
	 */
	public $total_stages = 0;

	/**
	 * Advice completed stages.
	 *
	 * @var int
	 */
	public $completed_stages = 0;

	/**
	 * Advice created at.
	 *
	 * @var string
	 */
	public $created_at = '';

	/**
	 * Advice updated at.
	 *
	 * @var string
	 */
	public $updated_at = '';

	/**
	 * Is valid model.
	 *
	 * @return bool
	 */
	public function isValid() {
		return ! empty( $this->id ) && ! empty( $this->type ) && ! empty( $this->status );
	}

	/**
	 * To array.
	 *
	 * @return array
	 */
	public function toArray() {
		return array(
			'id'                   => $this->id,
			'type'                 => $this->type,
			'status'               => $this->status,
			'description'          => $this->description,
			'detailed_description' => $this->detailed_description,
			'total_stages'         => $this->total_stages,
			'completed_stages'     => $this->completed_stages,
			'created_at'           => $this->created_at,
			'updated_at'           => $this->updated_at,
		);
	}

	/**
	 * Get stage percent.
	 *
	 * @return float
	 */
	public function stagePercent() {
		$total     = $this->total_stages;
		$completed = $this->completed_stages;

		if ( $total > 0 ) {
			return round( $completed / $total * 100 );
		}

		return 0;
	}

	/**
	 * Get spinner percent.
	 *
	 * @return string
	 */
	public function spinnerPercent() {
		$percent = $this->stagePercent();
		if ( $percent > 0 ) {
			return round( $percent / 10 ) . '0';
		}

		return '0';
	}
}
