<?php
/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2022 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace CloudLinux\SmartAdvice\App\Cli;

use WP_CLI;
use WP_CLI_Command;

/**
 * CLI commands
 */
class Commands extends WP_CLI_Command {
	/**
	 * Sync advices.
	 *
	 * @param  array $args  args.
	 * @param  array $assoc_args  args.
	 *
	 * @return void
	 */
	public function sync( $args = array(), $assoc_args = array() ) {
		$list = array_key_exists( 'list', $assoc_args ) ? $assoc_args['list'] : '';
		$data = json_decode( $list, true );

		if ( ! is_array( $data ) ) {
			// @phpcs:ignore WordPress.PHP.DevelopmentFunctions.error_log_print_r
			do_action( 'cl_smart_advice_set_error', E_WARNING, 'Json ' . print_r( $list, true ) . ' is invalid.', __FILE__, __LINE__ );
			WP_CLI::error( 'Json is invalid.' );
			exit( 1 );
		}

		do_action( 'cl_smart_advice_sync', $data );

		$failed = apply_filters( 'cl_smart_advice_sync_failed', false );

		if ( $failed ) {
			do_action( 'cl_smart_advice_set_error', E_WARNING, 'Failed sync advices.', __FILE__, __LINE__ );
			WP_CLI::error( 'Failed sync advices.' );
			exit( 1 );
		}

		WP_CLI::success( 'Ok' );
	}

	/**
	 * Apply advice.
	 *
	 * @param  array $args  args.
	 * @param  array $assoc_args  args.
	 *
	 * @return void
	 */
	public function apply( $args = array(), $assoc_args = array() ) {
		$advice_id = $this->adviceId( $assoc_args );
		do_action( 'cl_smart_advice_apply', $advice_id, true );
		WP_CLI::success( 'Ok' );
	}

	/**
	 * Rollback advice.
	 *
	 * @param  array $args  args.
	 * @param  array $assoc_args  args.
	 *
	 * @return void
	 */
	public function rollback( $args = array(), $assoc_args = array() ) {
		$advice_id = $this->adviceId( $assoc_args );
		do_action( 'cl_smart_advice_rollback', $advice_id, true );
		WP_CLI::success( 'Ok' );
	}

	/**
	 * Check advice id.
	 *
	 * @param  array $assoc_args  args.
	 *
	 * @return int|void
	 */
	private function adviceId( $assoc_args ) {
		$advice_id = array_key_exists( 'advice_id', $assoc_args ) ? $assoc_args['advice_id'] : 0;
		if ( 0 === (int) $advice_id ) {
			WP_CLI::error( 'Advice id is empty' );
			exit( 1 );
		}

		return $advice_id;
	}
}
