<?php
/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2022 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.
 * cloudlinux.
 * com/legal/
 */

namespace CloudLinux\SmartAdvice\App\Notice;

use CloudLinux\SmartAdvice\App\Model as BaseModel;

/**
 * Advice model
 */
class Model extends BaseModel {
	const ERROR_ADVICE_APPLY = array(
		'type'    => 'ERROR_ADVICE_APPLY',
		'class'   => 'error',
		'message' => 'Error applying advice, please try again later.',
	);

	const ERROR_ADVICE_ROLLBACK = array(
		'type'    => 'ERROR_ADVICE_ROLLBACK',
		'class'   => 'error',
		'message' => 'Rollback advice error, please try again later.',
	);

	const ERROR_ADVICE_NOT_FOUND = array(
		'type'    => 'ERROR_ADVICE_NOT_FOUND',
		'class'   => 'error',
		'message' => 'Advice not found.',
	);

	/**
	 * Advice ID.
	 *
	 * @var string
	 */
	public $id = '';

	/**
	 * Advice type.
	 *
	 * @var string
	 */
	public $type = '';

	/**
	 * Notice payload.
	 *
	 * @var array
	 */
	public $payload = array();

	/**
	 * Is valid model.
	 *
	 * @return bool
	 */
	public function isValid() {
		return ! empty( $this->id ) && ! empty( $this->type ) && is_array( $this->payload );
	}

	/**
	 * To array.
	 *
	 * @return array
	 */
	public function toArray() {
		return array(
			'id'      => $this->id,
			'type'    => $this->type,
			'payload' => $this->payload,
		);
	}

	/**
	 * Type info.
	 *
	 * @return string[]|null
	 */
	public function info() {
		switch ( $this->type ) {
			case self::ERROR_ADVICE_APPLY['type']:
				return self::ERROR_ADVICE_APPLY;
			case self::ERROR_ADVICE_ROLLBACK['type']:
				return self::ERROR_ADVICE_ROLLBACK;
			case self::ERROR_ADVICE_NOT_FOUND['type']:
				return self::ERROR_ADVICE_NOT_FOUND;
			default:
				return null;
		}
	}

	/**
	 * Html class.
	 *
	 * @return string
	 */
	public function htmlClass() {
		$info = $this->info();
		if ( is_array( $info ) && array_key_exists( 'class', $info ) ) {
			return $info['class'];
		}

		return '';
	}

	/**
	 * Html message.
	 *
	 * @return string
	 */
	public function htmlMessage() {
		$info    = $this->info();
		$message = '';

		if ( is_array( $info ) && array_key_exists( 'message', $info ) ) {
			$message = str_replace( '#url#', esc_attr( admin_url( 'options-general.php?page=' . CL_SMART_ADVICE_SLUG ) ), $info['message'] );
		}

		if ( array_key_exists( 'description', $this->payload ) ) {
			$message .= '<br>' . $this->payload['description'];
		}

		return $message;
	}
}
