<?php
/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2022 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace CloudLinux\SmartAdvice\App;

use CloudLinux\SmartAdvice\App\Advice\Api;
use CloudLinux\SmartAdvice\App\Advice\ApiSocket;
use CloudLinux\SmartAdvice\App\Advice\Manager as AdviceManager;
use CloudLinux\SmartAdvice\App\Notice\Manager as NoticeManager;
use CloudLinux\SmartAdvice\App\Views\Admin;
use CloudLinux\SmartAdvice\App\Views\Settings;
use CloudLinux\SmartAdvice\App\Views\Widget;

/**
 * Initial class
 */
class Plugin {
	/**
	 * Self instance
	 *
	 * @var ?self
	 */
	private static $instance = null;

	/**
	 * Container.
	 *
	 * @var array
	 */
	private $container = array();

	/**
	 * Private constructor
	 */
	private function __construct() {
	}

	/**
	 * Private clone
	 */
	private function __clone() {
	}

	/**
	 * Get instance
	 *
	 * @return self
	 */
	public static function instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Get service
	 *
	 * @param string $key class.
	 *
	 * @return mixed
	 */
	public function get( $key ) {
		if ( array_key_exists( $key, $this->container ) ) {
			return $this->container[ $key ];
		}

		return null;
	}

	/**
	 * Setup container.
	 *
	 * @return void
	 */
	private function setup() {
		$this->container[ Debug::class ]  = new Debug();
		$this->container[ Api::class ]    = new ApiSocket();
		$this->container[ Option::class ] = new Option();

		$this->container[ AdviceManager::class ] = new AdviceManager( $this->get( Api::class ), $this->get( Option::class ) );
		$this->container[ NoticeManager::class ] = new NoticeManager( $this->get( Option::class ) );

		$this->container[ Admin::class ]    = new Admin( $this->get( AdviceManager::class ) );
		$this->container[ Widget::class ]   = new Widget( $this->get( AdviceManager::class ) );
		$this->container[ Settings::class ] = new Settings( $this->get( AdviceManager::class ), $this->get( NoticeManager::class ) );
	}

	/**
	 * Init plugin.
	 *
	 * @return void
	 */
	public function init() {
		if ( is_admin() || ( defined( 'WP_CLI' ) && WP_CLI ) ) {
			$this->setup();
		}
	}
}
