<?php
/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2022 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace CloudLinux\SmartAdvice\App\Views;

use CloudLinux\SmartAdvice\App\Advice\Manager;
use CloudLinux\SmartAdvice\App\View;

/**
 * Admin
 */
class Admin extends View {
	/**
	 * Advice manager.
	 *
	 * @var Manager
	 */
	private $manager;

	/**
	 * Constructor.
	 *
	 * @param  Manager $manager  advice.
	 */
	public function __construct( Manager $manager ) {
		$this->manager = $manager;

		add_action( 'admin_enqueue_scripts', array( $this, 'scripts' ) );
		add_action( 'cl_smart_advice_uninstalled', array( $this, 'uninstalled' ) );
		add_action( 'shutdown', array( $this, 'shutdown' ) );
	}

	/**
	 * Scripts and styles.
	 *
	 * @param  string $hook_suffix  The current admin page.
	 *
	 * @return void
	 */
	public function scripts( $hook_suffix ) {
		wp_register_style( 'cl-smart-advice-admin', false, array(), CL_SMART_ADVICE_VERSION );
		// @phpcs:ignore WordPress.WP.AlternativeFunctions.file_get_contents_file_get_contents
		wp_add_inline_style( 'cl-smart-advice-admin', file_get_contents( CL_SMART_ADVICE_FOLDER_PATH . '/assets/admin.css' ) );
		wp_enqueue_style( 'cl-smart-advice-admin' );

		wp_register_script( 'cl-smart-advice-admin', false, array( 'jquery' ), CL_SMART_ADVICE_VERSION, true );
		wp_enqueue_script( 'cl-smart-advice-admin' );
		// @phpcs:ignore WordPress.WP.AlternativeFunctions.file_get_contents_file_get_contents
		wp_add_inline_script( 'cl-smart-advice-admin', file_get_contents( CL_SMART_ADVICE_FOLDER_PATH . '/assets/admin.js' ) );
	}

	/**
	 * Plugin uninstalled.
	 *
	 * @return void
	 */
	public function shutdown() {
		if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) {
			return;
		}

		$manager = $this->manager;

		if ( ! $manager->compatible() ) {
			return;
		}

		$sync_failed = apply_filters( 'cl_smart_advice_sync_failed', false );

		if (
			( empty( $manager->syncAt() ) && $sync_failed ) ||
			( ! empty( $manager->syncAt() ) && empty( $manager->advices() ) && ! $sync_failed )
		) {
			do_action( 'cl_smart_advice_deleting' );

			if ( is_link( CL_SMART_ADVICE_SYMLINK_FILE_PATH ) ) {
				do_action( 'cl_smart_advice_set_error_handler' );
				unlink( CL_SMART_ADVICE_SYMLINK_FILE_PATH );
				do_action( 'cl_smart_advice_restore_error_handler' );

				if ( ! defined( 'WP_CLI' ) ) {
					wp_safe_redirect( admin_url() );
				}
				exit;
			}
		}
	}
}

