# -*- coding: utf-8 -*-

# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2021 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT

"""
This module contains X Ray Smart Advice local utility main run function
"""
import sys

from xray.adviser.cli_api import SmartAdviceUtil
from xray.cli_utils.cmdline_parser import (
    cmd_parser_adviser,
    parse_cmd_arguments
)
from xray.cli_utils.validations import validate_adviser
from xray.internal.constants import adviser_log
from xray.internal.exceptions import XRayError
from xray.internal.user_plugin_utils import root_execution_only_check
from xray.internal.utils import configure_logging
from xray.internal.user_plugin_utils import get_xray_exec_user


def run():
    """
    X Ray Smart Advice run function
    """
    root_execution_only_check()
    configure_logging(adviser_log)
    raw_args = parse_cmd_arguments(cmd_parser_adviser())
    args = validate_adviser(raw_args.__dict__)

    try:
        sa = SmartAdviceUtil()
        if args.command == 'list':
            result = sa.advice_list(extended=args.extends)
        elif args.command == 'sites-status':
            # because from user plugin UI it works via XRAYEXEC_UID envvar
            username = args.username or get_xray_exec_user()
            if not username:
                print('parameter --username must be specified')
                sys.exit(1)
            result = sa.get_site_statuses(username=username)
        elif args.command == 'details':
            result = sa.advice_details(args.advice_id)
        elif args.command == 'apply':
            result = sa.manage_advice('apply', args.advice_id,
                                      ignore_errors=args.ignore_errors,
                                      async_mode=args.async_mode,
                                      source=args.source)
        elif args.command == 'rollback':
            result = sa.manage_advice('rollback', args.advice_id,
                                      async_mode=args.async_mode,
                                      source=args.source,
                                      reason=args.reason)
        elif args.command == 'counters':
            result = sa.advice_counters()
        elif args.command == 'status':
            result = sa.manage_advice_status(args.advice_id)
        elif args.command == 'wordpress-plugin-install':
            result = sa.sync_advices_wordpress_plugin()
        else:
            raise SystemExit('Unknown action')
        if result:
            print(result)
    except XRayError as e:
        print(e)
        sys.exit(1)
